netapp_ontap.models.port_lag API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.port_lag`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class PortLagSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the PortLag object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `active_ports: List[Port] GET`

    Active ports of a LAG (ifgrp). (Some member ports may be inactive.)

  `distribution_policy: str GET POST`

    Policy for mapping flows to ports for outbound packets through a LAG (ifgrp).

    Valid choices:

    - port
    - ip
    - mac
    - sequential
  `member_ports: List[Port] GET POST PATCH`

    Array of ports belonging to the LAG, regardless of their state.

  `mode: str GET POST`

    Determines how the ports interact with the switch.

    Valid choices:

    - multimode_lacp
    - multimode
    - singlemode